ImageChecks extension

Enable Image checks.

Under the hood, this extension uses the LegacyMatcher extension to support legacy matchers.

on

Methods

matchesGoldenFile(Uri key, {int? version}) Future<void>

Available on Subject<Image>, provided by the ImageChecks extension

Asserts that an Image matches the golden image file identified by key, with an optional version number.
matchesGoldenFileStringPath(String key, int? version) Future<void>

Available on Subject<Image>, provided by the ImageChecks extension

Asserts that an Image matches the golden image file identified by key, with an optional version number.
matchesReferenceImage(Image image) Future<void>

Available on Subject<Image>, provided by the ImageChecks extension

Asserts that an Image matches a reference image identified by image.